#! -*- coding: utf-8 -*-
import datetime

from django.test import TestCase

from .models import AcomeaClient, AcomeaClientRiservata, AcomeaClientCms, AcomeaClientRiservataCms


class ClientPubblicoTest(TestCase):
    def test_connection(self):
        """
        Giusto per controllare se nella rete in cui siamo la connessione ai server acomea c'è.
        """
        a = AcomeaClient()

    def test_get_last_data_quote(self):
        a = AcomeaClient()
        self.assertEqual(type(datetime.date.today()), type(a.get_last_data_quote()))

    def test_get_valori_riga_tabella_quote(self):
        a = AcomeaClient()
        dati = a.get_valori_riga_tabella_quote('MO', 'A1', datetime.date(2013, 1, 10))
        self.assertEqual('MO', dati.CODFON)
        self.assertEqual('A1', dati.CLASSE)
        self.assertEqual(20.277, dati.QUOTA)

    def test_get_fondi_per_tipo(self):
        a = AcomeaClient()
        for fondo in a.get_fondi_per_tipo('FF'):
            self.assertEqual('FF', fondo.TipoFondo)

    def test_check_cliente(self):
        a = AcomeaClient()
        c = a.check_cliente('CTTSMN77L08D969D')
        self.assertEqual(False, c.CanOperate)
        self.assertEqual('ClienteInesistente', c.CheckResult)

    def test_get_cliente(self):
        a = AcomeaClient()
        c = a.get_cliente('YNCRDI67S70Z216G')
        self.assertEqual("Gestioni Collettive", c[0].TIPO)


class ClientPubblicoCmsTest(TestCase):
    def test_connection(self):
        """
        Giusto per controllare se nella rete in cui siamo la connessione ai server acomea c'è.
        """
        a = AcomeaClientCms()

    def test_get_fondi(self):
        a = AcomeaClientCms()
        f = a.get_fondi()
        print f

    def test_get_classi_di_attivita(self):
        a = AcomeaClientCms()
        d = a.get_classi_di_attivita('MO')
        print d

    def test_get_grafico(self):
        a = AcomeaClientCms()
        f = a.get_grafico('MO', 'A1')
        print f


##todo testare tutta la app acomea.views.webservice

class ClientRiservatoTest(TestCase):
    def test_connection(self):
        """
        Giusto per controllare se nella rete in cui siamo la connessione ai server acomea c'è.
        """
        a = AcomeaClientRiservataCms()

    def test_get_cliente_esistente(self):
        a = AcomeaClientRiservataCms()
        soap_cliente = a.get_cliente('YNCRDI67S70Z216G')
        self.assertEqual('YNCRDI67S70Z216G', soap_cliente['CODFISC'])

    def test_get_cliente_inesistente(self):
        a = AcomeaClientRiservataCms()
        soap_cliente = a.get_cliente('CTTSMN77L08D969D')
        self.assertEqual(None, soap_cliente)

    def test_check_cliente(self):
        a = AcomeaClientRiservataCms()
        soap_cliente = a.get_cliente('YNCRDI67S70Z216G')
        result = a.check_cliente(soap_cliente['CodCliFC'], soap_cliente['CODFISC'], soap_cliente['DtNasc'])
        self.assertTrue(result)

    def test_get_riepilogo(self):
        a = AcomeaClientRiservataCms()
        soap_cliente = a.get_cliente('YNCRDI67S70Z216G')
        result = a.get_riepilogo('TUTTO', 'INTESTATARIO', soap_cliente['CODFISC'])
        self.assertTrue('valore_patrimonio' in result)
        self.assertTrue('utile_perdita' in result)
        self.assertTrue('saldo_sottoscrizioni' in result)

    def test_get_dettaglio(self):
        a = AcomeaClientRiservataCms()
        soap_cliente = a.get_cliente('VTLFBA66P10F205J')
        result = a.get_dettaglio('TUTTO', 'INTESTATARIO', soap_cliente['CODFISC'])
        print result